tlslite.handshakesettings

Package tlslite :: Module handshakesettings |
[hide private]
[frames] | no frames]

# Module handshakesettings

source code

Class for setting handshake parameters.

Classes | [hide private]
| HandshakeSettings This class encapsulates various parameters that can be used with a TLS handshake.

Variables | [hide private]
| CERTIFICATE_TYPES = ``[``'``x509``'``]``
| CIPHER_IMPLEMENTATIONS = ``[``'``openssl``'``,` `'``pycrypto``'``,` `'``python``'``]``
| CIPHER_NAMES = ``[``'``rc4``'``,` `'``aes256``'``,` `'``aes128``'``,` `'``3des``'``]``
| MAC_NAMES = ``[``'``sha``'``,` `'``sha256``'``]``
| __package__ = ``'``tlslite``'``